@@ -42,8 +42,8 @@ class ReportNewMems(Report):
                     get_value=lambda instance: instance.get_invoice().total if instance.get_invoice else '' ),
                 #ObjectValue(attribute_name='payment_method', left=15*cm),
                 ObjectValue(attribute_name='join_dt', left=14.5*cm,
-                    get_value=lambda instance: instance.join_dt.strftime('%m/%d/%Y')),
+                    get_value=lambda instance: instance.join_dt.strftime('%b %d, %Y')),
                 ObjectValue(attribute_name='expire_dt', left=17.5*cm,
-                    get_value=lambda instance: instance.expire_dt.strftime('%m/%d/%Y') if instance.expire_dt else ''),
+                    get_value=lambda instance: instance.expire_dt.strftime('%b %d, %Y') if instance.expire_dt else ''),
             )
     
